@@ -3,7 +3,7 @@ package Crypt::ScryptKDF;
 use strict;
 use warnings ;
 
-our $VERSION = '0.008_2';
+our $VERSION = '0.008_3';
 
 use MIME::Base64 qw(decode_base64 encode_base64);
 use Exporter 'import';
@@ -145,17 +145,21 @@ Crypt::ScryptKDF - Scrypt password based key derivation function
 
 =head1 SYNOPSIS
 
- ###### creating / verifying scrypt-based password hash
- use Crypt::ScryptKDF qw(scrypt_hash scrypt_hash_verify random_bytes);
+Creating / verifying scrypt-based password hash:
 
- my $hash = scrypt_hash("secret password");
+ use Crypt::ScryptKDF qw(scrypt_hash scrypt_hash_verify);
+
+ my $hash1 = scrypt_hash("secret password");
  # .. later
- die "Invalid password" unless scrypt_hash_verify("secret password", $hash);
+ die "Invalid password" unless scrypt_hash_verify("secret password", $hash1);
 
  #or by specifying Scrypt parameters
- my $hash = scrypt_hash($password, $salt, $N, $r, $p, $len);
+ my $hash2 = scrypt_hash("secret password", \32, 16384, 8, 1, 32);
+ # .. later
+ die "Invalid password" unless scrypt_hash_verify("secret password", $hash2);
+
+Creating raw scrypt-based derived key:
 
- ###### creating raw scrypt-based derived key
  use Crypt::ScryptKDF qw(scrypt_raw scrypt_hex scrypt_b64);
 
  my $binary_buffer = scrypt_raw($password, $salt, $N, $r, $p, $len);
@@ -177,7 +181,7 @@ It can be used for:
 
 =back
 
-More details about Scrypt: L<http://www.tarsnap.com/scrypt/scrypt.pdf> and L<https://tools.ietf.org/html/draft-josefsson-scrypt-kdf-00>
+More details about Scrypt: L<http://www.tarsnap.com/scrypt/scrypt.pdf> and L<https://tools.ietf.org/html/draft-josefsson-scrypt-kdf>
 
 B<IMPORTANT:> This module needs a cryptographically strong random
 number generator. It tries to use one of the following:
@@ -225,7 +229,7 @@ Similar to scrypt_raw only the return value is BASE64 encoded.
 
 =item * scrypt_hash
 
- my $hash_string = scrypt_hash($password, $salt, $N, $r, $p, $len);
+ my $hash = scrypt_hash($password, $salt, $N, $r, $p, $len);
  #  params same as by scrypt_raw, the $salt can also be a scalar ref with salt
  #  length e.g. $salt=\24 means that salt will be 24 randomly generated bytes
  #returns:
@@ -255,7 +259,7 @@ Some of the parameters are optional:
 =item * random_bytes
 
  my $salt = random_bytes($len);
- #  $len - number of ramdom bytes
+ #  $len - number of random bytes
  #returns:
  #  $len random octets
 
